# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: demoparser/protobufs/cstrike15_usermessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from demoparser.protobufs import netmessages_pb2 as demoparser_dot_protobufs_dot_netmessages__pb2
from demoparser.protobufs import cstrike15_gcmessages_pb2 as demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='demoparser/protobufs/cstrike15_usermessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n1demoparser/protobufs/cstrike15_usermessages.proto\x1a google/protobuf/descriptor.proto\x1a&demoparser/protobufs/netmessages.proto\x1a/demoparser/protobufs/cstrike15_gcmessages.proto\"\x82\x01\n\x12\x43\x43SUsrMsg_VGUIMenu\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04show\x18\x02 \x01(\x08\x12+\n\x07subkeys\x18\x03 \x03(\x0b\x32\x1a.CCSUsrMsg_VGUIMenu.Subkey\x1a#\n\x06Subkey\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03str\x18\x02 \x01(\t\"!\n\x10\x43\x43SUsrMsg_Geiger\x12\r\n\x05range\x18\x01 \x01(\x05\" \n\x0f\x43\x43SUsrMsg_Train\x12\r\n\x05train\x18\x01 \x01(\x05\"!\n\x11\x43\x43SUsrMsg_HudText\x12\x0c\n\x04text\x18\x01 \x01(\t\"U\n\x11\x43\x43SUsrMsg_SayText\x12\x0f\n\x07\x65nt_idx\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0c\n\x04\x63hat\x18\x03 \x01(\x08\x12\x13\n\x0btextallchat\x18\x04 \x01(\x08\"j\n\x12\x43\x43SUsrMsg_SayText2\x12\x0f\n\x07\x65nt_idx\x18\x01 \x01(\x05\x12\x0c\n\x04\x63hat\x18\x02 \x01(\x08\x12\x10\n\x08msg_name\x18\x03 \x01(\t\x12\x0e\n\x06params\x18\x04 \x03(\t\x12\x13\n\x0btextallchat\x18\x05 \x01(\x08\"4\n\x11\x43\x43SUsrMsg_TextMsg\x12\x0f\n\x07msg_dst\x18\x01 \x01(\x05\x12\x0e\n\x06params\x18\x03 \x03(\t\"\xe0\x01\n\x10\x43\x43SUsrMsg_HudMsg\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12\x1a\n\x03pos\x18\x02 \x01(\x0b\x32\r.CMsgVector2D\x12\x17\n\x04\x63lr1\x18\x03 \x01(\x0b\x32\t.CMsgRGBA\x12\x17\n\x04\x63lr2\x18\x04 \x01(\x0b\x32\t.CMsgRGBA\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x05 \x01(\x05\x12\x14\n\x0c\x66\x61\x64\x65_in_time\x18\x06 \x01(\x02\x12\x15\n\rfade_out_time\x18\x07 \x01(\x02\x12\x11\n\thold_time\x18\t \x01(\x02\x12\x0f\n\x07\x66x_time\x18\n \x01(\x02\x12\x0c\n\x04text\x18\x0b \x01(\t\"`\n\x0f\x43\x43SUsrMsg_Shake\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x05\x12\x17\n\x0flocal_amplitude\x18\x02 \x01(\x02\x12\x11\n\tfrequency\x18\x03 \x01(\x02\x12\x10\n\x08\x64uration\x18\x04 \x01(\x02\"\\\n\x0e\x43\x43SUsrMsg_Fade\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x11\n\thold_time\x18\x02 \x01(\x05\x12\r\n\x05\x66lags\x18\x03 \x01(\x05\x12\x16\n\x03\x63lr\x18\x04 \x01(\x0b\x32\t.CMsgRGBA\">\n\x10\x43\x43SUsrMsg_Rumble\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x05\x12\r\n\x05\x66lags\x18\x03 \x01(\x05\"M\n\x16\x43\x43SUsrMsg_CloseCaption\x12\x0c\n\x04hash\x18\x01 \x01(\r\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x13\n\x0b\x66rom_player\x18\x03 \x01(\x08\"S\n\x1c\x43\x43SUsrMsg_CloseCaptionDirect\x12\x0c\n\x04hash\x18\x01 \x01(\r\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x13\n\x0b\x66rom_player\x18\x03 \x01(\x08\"*\n\x13\x43\x43SUsrMsg_SendAudio\x12\x13\n\x0bradio_sound\x18\x01 \x01(\t\"]\n\x12\x43\x43SUsrMsg_RawAudio\x12\r\n\x05pitch\x18\x01 \x01(\x05\x12\x0e\n\x06\x65ntidx\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x02\x12\x16\n\x0evoice_filename\x18\x04 \x01(\t\"\xa1\x01\n\x13\x43\x43SUsrMsg_VoiceMask\x12\x35\n\x0cplayer_masks\x18\x01 \x03(\x0b\x32\x1f.CCSUsrMsg_VoiceMask.PlayerMask\x12\x19\n\x11player_mod_enable\x18\x02 \x01(\x08\x1a\x38\n\nPlayerMask\x12\x17\n\x0fgame_rules_mask\x18\x01 \x01(\x05\x12\x11\n\tban_masks\x18\x02 \x01(\x05\"e\n\x10\x43\x43SUsrMsg_Damage\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\x12(\n\x13inflictor_world_pos\x18\x02 \x01(\x0b\x32\x0b.CMsgVector\x12\x17\n\x0fvictim_entindex\x18\x03 \x01(\x05\"X\n\x13\x43\x43SUsrMsg_RadioText\x12\x0f\n\x07msg_dst\x18\x01 \x01(\x05\x12\x0e\n\x06\x63lient\x18\x02 \x01(\x05\x12\x10\n\x08msg_name\x18\x03 \x01(\t\x12\x0e\n\x06params\x18\x04 \x03(\t\"\"\n\x12\x43\x43SUsrMsg_HintText\x12\x0c\n\x04text\x18\x01 \x01(\t\"&\n\x15\x43\x43SUsrMsg_KeyHintText\x12\r\n\x05hints\x18\x01 \x03(\t\"\xd6\x02\n$CCSUsrMsg_ProcessSpottedEntityUpdate\x12\x12\n\nnew_update\x18\x01 \x01(\x08\x12Q\n\x0e\x65ntity_updates\x18\x02 \x03(\x0b\x32\x39.CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate\x1a\xc6\x01\n\x13SpottedEntityUpdate\x12\x12\n\nentity_idx\x18\x01 \x01(\x05\x12\x10\n\x08\x63lass_id\x18\x02 \x01(\x05\x12\x10\n\x08origin_x\x18\x03 \x01(\x05\x12\x10\n\x08origin_y\x18\x04 \x01(\x05\x12\x10\n\x08origin_z\x18\x05 \x01(\x05\x12\x0f\n\x07\x61ngle_y\x18\x06 \x01(\x05\x12\x0f\n\x07\x64\x65\x66user\x18\x07 \x01(\x08\x12\x1a\n\x12player_has_defuser\x18\x08 \x01(\x08\x12\x15\n\rplayer_has_c4\x18\t \x01(\x08\"S\n\x1d\x43\x43SUsrMsg_SendPlayerItemDrops\x12\x32\n\x0e\x65ntity_updates\x18\x01 \x03(\x0b\x32\x1a.CEconItemPreviewDataBlock\"_\n\x1d\x43\x43SUsrMsg_SendPlayerItemFound\x12,\n\x08iteminfo\x18\x01 \x01(\x0b\x32\x1a.CEconItemPreviewDataBlock\x12\x10\n\x08\x65ntindex\x18\x02 \x01(\x05\"o\n\x16\x43\x43SUsrMsg_ReloadEffect\x12\x0e\n\x06\x65ntidx\x18\x01 \x01(\x05\x12\x0f\n\x07\x61\x63tanim\x18\x02 \x01(\x05\x12\x10\n\x08origin_x\x18\x03 \x01(\x02\x12\x10\n\x08origin_y\x18\x04 \x01(\x02\x12\x10\n\x08origin_z\x18\x05 \x01(\x02\"\'\n\x15\x43\x43SUsrMsg_AdjustMoney\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x05\"U\n\x13\x43\x43SUsrMsg_ReportHit\x12\r\n\x05pos_x\x18\x01 \x01(\x02\x12\r\n\x05pos_y\x18\x02 \x01(\x02\x12\x11\n\ttimestamp\x18\x04 \x01(\x02\x12\r\n\x05pos_z\x18\x03 \x01(\x02\"R\n\x11\x43\x43SUsrMsg_KillCam\x12\x10\n\x08obs_mode\x18\x01 \x01(\x05\x12\x14\n\x0c\x66irst_target\x18\x02 \x01(\x05\x12\x15\n\rsecond_target\x18\x03 \x01(\x05\"\x8b\x01\n\x1a\x43\x43SUsrMsg_DesiredTimescale\x12\x19\n\x11\x64\x65sired_timescale\x18\x01 \x01(\x02\x12\x1d\n\x15\x64uration_realtime_sec\x18\x02 \x01(\x02\x12\x19\n\x11interpolator_type\x18\x03 \x01(\x05\x12\x18\n\x10start_blend_time\x18\x04 \x01(\x02\"3\n\x1a\x43\x43SUsrMsg_CurrentTimescale\x12\x15\n\rcur_timescale\x18\x01 \x01(\x02\"Q\n\x1a\x43\x43SUsrMsg_AchievementEvent\x12\x13\n\x0b\x61\x63hievement\x18\x01 \x01(\x05\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0f\n\x07user_id\x18\x03 \x01(\x05\"r\n\x1c\x43\x43SUsrMsg_MatchEndConditions\x12\x11\n\tfraglimit\x18\x01 \x01(\x05\x12\x14\n\x0cmp_maxrounds\x18\x02 \x01(\x05\x12\x13\n\x0bmp_winlimit\x18\x03 \x01(\x05\x12\x14\n\x0cmp_timelimit\x18\x04 \x01(\x05\"\xa2\x01\n\x1b\x43\x43SUsrMsg_PlayerStatsUpdate\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x30\n\x05stats\x18\x04 \x03(\x0b\x32!.CCSUsrMsg_PlayerStatsUpdate.Stat\x12\x0f\n\x07user_id\x18\x05 \x01(\x05\x12\x0b\n\x03\x63rc\x18\x06 \x01(\x05\x1a\"\n\x04Stat\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\r\n\x05\x64\x65lta\x18\x02 \x01(\x05\">\n\x1a\x43\x43SUsrMsg_DisplayInventory\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\"p\n\x17\x43\x43SUsrMsg_QuestProgress\x12\x10\n\x08quest_id\x18\x01 \x01(\r\x12\x15\n\rnormal_points\x18\x02 \x01(\r\x12\x14\n\x0c\x62onus_points\x18\x03 \x01(\r\x12\x16\n\x0eis_event_quest\x18\x04 \x01(\x08\"E\n\x1e\x43\x43SUsrMsg_ScoreLeaderboardData\x12#\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.ScoreLeaderboardData\"S\n%CCSUsrMsg_PlayerDecalDigitalSignature\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1c.PlayerDecalDigitalSignature\":\n\x12\x43\x43SUsrMsg_XRankGet\x12\x10\n\x08mode_idx\x18\x01 \x01(\x05\x12\x12\n\ncontroller\x18\x02 \x01(\x05\"K\n\x12\x43\x43SUsrMsg_XRankUpd\x12\x10\n\x08mode_idx\x18\x01 \x01(\x05\x12\x12\n\ncontroller\x18\x02 \x01(\x05\x12\x0f\n\x07ranking\x18\x03 \x01(\x05\"8\n\x18\x43\x43SUsrMsg_CallVoteFailed\x12\x0e\n\x06reason\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\x05\"\x9e\x01\n\x13\x43\x43SUsrMsg_VoteStart\x12\x0c\n\x04team\x18\x01 \x01(\x05\x12\x0f\n\x07\x65nt_idx\x18\x02 \x01(\x05\x12\x11\n\tvote_type\x18\x03 \x01(\x05\x12\x10\n\x08\x64isp_str\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65tails_str\x18\x05 \x01(\t\x12\x16\n\x0eother_team_str\x18\x06 \x01(\t\x12\x16\n\x0eis_yes_no_vote\x18\x07 \x01(\x08\"\\\n\x12\x43\x43SUsrMsg_VotePass\x12\x0c\n\x04team\x18\x01 \x01(\x05\x12\x11\n\tvote_type\x18\x02 \x01(\x05\x12\x10\n\x08\x64isp_str\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tails_str\x18\x04 \x01(\t\"4\n\x14\x43\x43SUsrMsg_VoteFailed\x12\x0c\n\x04team\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\x05\"/\n\x13\x43\x43SUsrMsg_VoteSetup\x12\x18\n\x10potential_issues\x18\x01 \x03(\t\"\x84\x01\n&CCSUsrMsg_SendLastKillerDamageToClient\x12\x16\n\x0enum_hits_given\x18\x01 \x01(\x05\x12\x14\n\x0c\x64\x61mage_given\x18\x02 \x01(\x05\x12\x16\n\x0enum_hits_taken\x18\x03 \x01(\x05\x12\x14\n\x0c\x64\x61mage_taken\x18\x04 \x01(\x05\"\xc6\x01\n\x1a\x43\x43SUsrMsg_ServerRankUpdate\x12;\n\x0brank_update\x18\x01 \x03(\x0b\x32&.CCSUsrMsg_ServerRankUpdate.RankUpdate\x1ak\n\nRankUpdate\x12\x12\n\naccount_id\x18\x01 \x01(\x05\x12\x10\n\x08rank_old\x18\x02 \x01(\x05\x12\x10\n\x08rank_new\x18\x03 \x01(\x05\x12\x10\n\x08num_wins\x18\x04 \x01(\x05\x12\x13\n\x0brank_change\x18\x05 \x01(\x02\"Q\n\x12\x43\x43SUsrMsg_XpUpdate\x12;\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32-.CMsgGCCstrike15_v2_GC2ServerNotifyXPRewarded\"$\n\x14\x43\x43SUsrMsg_ItemPickup\x12\x0c\n\x04item\x18\x01 \x01(\t\"Y\n\x12\x43\x43SUsrMsg_ShowMenu\x12\x18\n\x10\x62its_valid_slots\x18\x01 \x01(\x05\x12\x14\n\x0c\x64isplay_time\x18\x02 \x01(\x05\x12\x13\n\x0bmenu_string\x18\x03 \x01(\t\"!\n\x11\x43\x43SUsrMsg_BarTime\x12\x0c\n\x04time\x18\x01 \x01(\t\"\'\n\x14\x43\x43SUsrMsg_AmmoDenied\x12\x0f\n\x07\x61mmoIdx\x18\x01 \x01(\x05\"0\n\x19\x43\x43SUsrMsg_MarkAchievement\x12\x13\n\x0b\x61\x63hievement\x18\x01 \x01(\t\",\n\x1a\x43\x43SUsrMsg_MatchStatsUpdate\x12\x0e\n\x06update\x18\x01 \x01(\t\"3\n\x12\x43\x43SUsrMsg_ItemDrop\x12\x0e\n\x06itemid\x18\x01 \x01(\x03\x12\r\n\x05\x64\x65\x61th\x18\x02 \x01(\x08\"+\n\x19\x43\x43SUsrMsg_GlowPropTurnOff\x12\x0e\n\x06\x65ntidx\x18\x01 \x01(\x05\"b\n\x1e\x43\x43SUsrMsg_RoundBackupFilenames\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\r\n\x05index\x18\x02 \x01(\x05\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08nicename\x18\x04 \x01(\t\"#\n\x12\x43\x43SUsrMsg_ResetHud\x12\r\n\x05reset\x18\x01 \x01(\x08\"$\n\x13\x43\x43SUsrMsg_GameTitle\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\"\'\n\x16\x43\x43SUsrMsg_RequestState\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\",\n\x1b\x43\x43SUsrMsg_StopSpectatorMode\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\",\n\x1b\x43\x43SUsrMsg_DisconnectToLobby\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\")\n\x18\x43\x43SUsrMsg_WarmupHasEnded\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\"%\n\x14\x43\x43SUsrMsg_ClientInfo\x12\r\n\x05\x64ummy\x18\x01 \x01(\x05\">\n\x1d\x43\x43SUsrMsg_ServerRankRevealAll\x12\x1d\n\x15seconds_till_shutdown\x18\x01 \x01(\x05*\x99\x0c\n\x16\x45\x43strike15UserMessages\x12\x12\n\x0e\x43S_UM_VGUIMenu\x10\x01\x12\x10\n\x0c\x43S_UM_Geiger\x10\x02\x12\x0f\n\x0b\x43S_UM_Train\x10\x03\x12\x11\n\rCS_UM_HudText\x10\x04\x12\x11\n\rCS_UM_SayText\x10\x05\x12\x12\n\x0e\x43S_UM_SayText2\x10\x06\x12\x11\n\rCS_UM_TextMsg\x10\x07\x12\x10\n\x0c\x43S_UM_HudMsg\x10\x08\x12\x12\n\x0e\x43S_UM_ResetHud\x10\t\x12\x13\n\x0f\x43S_UM_GameTitle\x10\n\x12\x0f\n\x0b\x43S_UM_Shake\x10\x0c\x12\x0e\n\nCS_UM_Fade\x10\r\x12\x10\n\x0c\x43S_UM_Rumble\x10\x0e\x12\x16\n\x12\x43S_UM_CloseCaption\x10\x0f\x12\x1c\n\x18\x43S_UM_CloseCaptionDirect\x10\x10\x12\x13\n\x0f\x43S_UM_SendAudio\x10\x11\x12\x12\n\x0e\x43S_UM_RawAudio\x10\x12\x12\x13\n\x0f\x43S_UM_VoiceMask\x10\x13\x12\x16\n\x12\x43S_UM_RequestState\x10\x14\x12\x10\n\x0c\x43S_UM_Damage\x10\x15\x12\x13\n\x0f\x43S_UM_RadioText\x10\x16\x12\x12\n\x0e\x43S_UM_HintText\x10\x17\x12\x15\n\x11\x43S_UM_KeyHintText\x10\x18\x12$\n CS_UM_ProcessSpottedEntityUpdate\x10\x19\x12\x16\n\x12\x43S_UM_ReloadEffect\x10\x1a\x12\x15\n\x11\x43S_UM_AdjustMoney\x10\x1b\x12\x19\n\x15\x43S_UM_UpdateTeamMoney\x10\x1c\x12\x1b\n\x17\x43S_UM_StopSpectatorMode\x10\x1d\x12\x11\n\rCS_UM_KillCam\x10\x1e\x12\x1a\n\x16\x43S_UM_DesiredTimescale\x10\x1f\x12\x1a\n\x16\x43S_UM_CurrentTimescale\x10 \x12\x1a\n\x16\x43S_UM_AchievementEvent\x10!\x12\x1c\n\x18\x43S_UM_MatchEndConditions\x10\"\x12\x1b\n\x17\x43S_UM_DisconnectToLobby\x10#\x12\x1b\n\x17\x43S_UM_PlayerStatsUpdate\x10$\x12\x1a\n\x16\x43S_UM_DisplayInventory\x10%\x12\x18\n\x14\x43S_UM_WarmupHasEnded\x10&\x12\x14\n\x10\x43S_UM_ClientInfo\x10\'\x12\x12\n\x0e\x43S_UM_XRankGet\x10(\x12\x12\n\x0e\x43S_UM_XRankUpd\x10)\x12\x18\n\x14\x43S_UM_CallVoteFailed\x10-\x12\x13\n\x0f\x43S_UM_VoteStart\x10.\x12\x12\n\x0e\x43S_UM_VotePass\x10/\x12\x14\n\x10\x43S_UM_VoteFailed\x10\x30\x12\x13\n\x0f\x43S_UM_VoteSetup\x10\x31\x12\x1d\n\x19\x43S_UM_ServerRankRevealAll\x10\x32\x12&\n\"CS_UM_SendLastKillerDamageToClient\x10\x33\x12\x1a\n\x16\x43S_UM_ServerRankUpdate\x10\x34\x12\x14\n\x10\x43S_UM_ItemPickup\x10\x35\x12\x12\n\x0e\x43S_UM_ShowMenu\x10\x36\x12\x11\n\rCS_UM_BarTime\x10\x37\x12\x14\n\x10\x43S_UM_AmmoDenied\x10\x38\x12\x19\n\x15\x43S_UM_MarkAchievement\x10\x39\x12\x1a\n\x16\x43S_UM_MatchStatsUpdate\x10:\x12\x12\n\x0e\x43S_UM_ItemDrop\x10;\x12\x19\n\x15\x43S_UM_GlowPropTurnOff\x10<\x12\x1d\n\x19\x43S_UM_SendPlayerItemDrops\x10=\x12\x1e\n\x1a\x43S_UM_RoundBackupFilenames\x10>\x12\x1d\n\x19\x43S_UM_SendPlayerItemFound\x10?\x12\x13\n\x0f\x43S_UM_ReportHit\x10@\x12\x12\n\x0e\x43S_UM_XpUpdate\x10\x41\x12\x17\n\x13\x43S_UM_QuestProgress\x10\x42\x12\x1e\n\x1a\x43S_UM_ScoreLeaderboardData\x10\x43\x12%\n!CS_UM_PlayerDecalDigitalSignature\x10\x44\x42\x05H\x01\x80\x01\x00')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,demoparser_dot_protobufs_dot_netmessages__pb2.DESCRIPTOR,demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_ECSTRIKE15USERMESSAGES = _descriptor.EnumDescriptor(
  name='ECstrike15UserMessages',
  full_name='ECstrike15UserMessages',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VGUIMenu', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Geiger', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Train', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_HudText', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SayText', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SayText2', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_TextMsg', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_HudMsg', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ResetHud', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_GameTitle', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Shake', index=10, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Fade', index=11, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Rumble', index=12, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_CloseCaption', index=13, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_CloseCaptionDirect', index=14, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SendAudio', index=15, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_RawAudio', index=16, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VoiceMask', index=17, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_RequestState', index=18, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_Damage', index=19, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_RadioText', index=20, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_HintText', index=21, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_KeyHintText', index=22, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ProcessSpottedEntityUpdate', index=23, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ReloadEffect', index=24, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_AdjustMoney', index=25, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_UpdateTeamMoney', index=26, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_StopSpectatorMode', index=27, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_KillCam', index=28, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_DesiredTimescale', index=29, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_CurrentTimescale', index=30, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_AchievementEvent', index=31, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_MatchEndConditions', index=32, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_DisconnectToLobby', index=33, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_PlayerStatsUpdate', index=34, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_DisplayInventory', index=35, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_WarmupHasEnded', index=36, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ClientInfo', index=37, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_XRankGet', index=38, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_XRankUpd', index=39, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_CallVoteFailed', index=40, number=45,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VoteStart', index=41, number=46,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VotePass', index=42, number=47,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VoteFailed', index=43, number=48,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_VoteSetup', index=44, number=49,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ServerRankRevealAll', index=45, number=50,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SendLastKillerDamageToClient', index=46, number=51,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ServerRankUpdate', index=47, number=52,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ItemPickup', index=48, number=53,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ShowMenu', index=49, number=54,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_BarTime', index=50, number=55,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_AmmoDenied', index=51, number=56,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_MarkAchievement', index=52, number=57,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_MatchStatsUpdate', index=53, number=58,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ItemDrop', index=54, number=59,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_GlowPropTurnOff', index=55, number=60,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SendPlayerItemDrops', index=56, number=61,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_RoundBackupFilenames', index=57, number=62,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_SendPlayerItemFound', index=58, number=63,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ReportHit', index=59, number=64,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_XpUpdate', index=60, number=65,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_QuestProgress', index=61, number=66,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_ScoreLeaderboardData', index=62, number=67,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CS_UM_PlayerDecalDigitalSignature', index=63, number=68,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5452,
  serialized_end=7013,
)
_sym_db.RegisterEnumDescriptor(_ECSTRIKE15USERMESSAGES)

ECstrike15UserMessages = enum_type_wrapper.EnumTypeWrapper(_ECSTRIKE15USERMESSAGES)
CS_UM_VGUIMenu = 1
CS_UM_Geiger = 2
CS_UM_Train = 3
CS_UM_HudText = 4
CS_UM_SayText = 5
CS_UM_SayText2 = 6
CS_UM_TextMsg = 7
CS_UM_HudMsg = 8
CS_UM_ResetHud = 9
CS_UM_GameTitle = 10
CS_UM_Shake = 12
CS_UM_Fade = 13
CS_UM_Rumble = 14
CS_UM_CloseCaption = 15
CS_UM_CloseCaptionDirect = 16
CS_UM_SendAudio = 17
CS_UM_RawAudio = 18
CS_UM_VoiceMask = 19
CS_UM_RequestState = 20
CS_UM_Damage = 21
CS_UM_RadioText = 22
CS_UM_HintText = 23
CS_UM_KeyHintText = 24
CS_UM_ProcessSpottedEntityUpdate = 25
CS_UM_ReloadEffect = 26
CS_UM_AdjustMoney = 27
CS_UM_UpdateTeamMoney = 28
CS_UM_StopSpectatorMode = 29
CS_UM_KillCam = 30
CS_UM_DesiredTimescale = 31
CS_UM_CurrentTimescale = 32
CS_UM_AchievementEvent = 33
CS_UM_MatchEndConditions = 34
CS_UM_DisconnectToLobby = 35
CS_UM_PlayerStatsUpdate = 36
CS_UM_DisplayInventory = 37
CS_UM_WarmupHasEnded = 38
CS_UM_ClientInfo = 39
CS_UM_XRankGet = 40
CS_UM_XRankUpd = 41
CS_UM_CallVoteFailed = 45
CS_UM_VoteStart = 46
CS_UM_VotePass = 47
CS_UM_VoteFailed = 48
CS_UM_VoteSetup = 49
CS_UM_ServerRankRevealAll = 50
CS_UM_SendLastKillerDamageToClient = 51
CS_UM_ServerRankUpdate = 52
CS_UM_ItemPickup = 53
CS_UM_ShowMenu = 54
CS_UM_BarTime = 55
CS_UM_AmmoDenied = 56
CS_UM_MarkAchievement = 57
CS_UM_MatchStatsUpdate = 58
CS_UM_ItemDrop = 59
CS_UM_GlowPropTurnOff = 60
CS_UM_SendPlayerItemDrops = 61
CS_UM_RoundBackupFilenames = 62
CS_UM_SendPlayerItemFound = 63
CS_UM_ReportHit = 64
CS_UM_XpUpdate = 65
CS_UM_QuestProgress = 66
CS_UM_ScoreLeaderboardData = 67
CS_UM_PlayerDecalDigitalSignature = 68



_CCSUSRMSG_VGUIMENU_SUBKEY = _descriptor.Descriptor(
  name='Subkey',
  full_name='CCSUsrMsg_VGUIMenu.Subkey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CCSUsrMsg_VGUIMenu.Subkey.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='str', full_name='CCSUsrMsg_VGUIMenu.Subkey.str', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=307,
)

_CCSUSRMSG_VGUIMENU = _descriptor.Descriptor(
  name='CCSUsrMsg_VGUIMenu',
  full_name='CCSUsrMsg_VGUIMenu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CCSUsrMsg_VGUIMenu.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show', full_name='CCSUsrMsg_VGUIMenu.show', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subkeys', full_name='CCSUsrMsg_VGUIMenu.subkeys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CCSUSRMSG_VGUIMENU_SUBKEY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=307,
)


_CCSUSRMSG_GEIGER = _descriptor.Descriptor(
  name='CCSUsrMsg_Geiger',
  full_name='CCSUsrMsg_Geiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='CCSUsrMsg_Geiger.range', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=342,
)


_CCSUSRMSG_TRAIN = _descriptor.Descriptor(
  name='CCSUsrMsg_Train',
  full_name='CCSUsrMsg_Train',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='train', full_name='CCSUsrMsg_Train.train', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=376,
)


_CCSUSRMSG_HUDTEXT = _descriptor.Descriptor(
  name='CCSUsrMsg_HudText',
  full_name='CCSUsrMsg_HudText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CCSUsrMsg_HudText.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=411,
)


_CCSUSRMSG_SAYTEXT = _descriptor.Descriptor(
  name='CCSUsrMsg_SayText',
  full_name='CCSUsrMsg_SayText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ent_idx', full_name='CCSUsrMsg_SayText.ent_idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CCSUsrMsg_SayText.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chat', full_name='CCSUsrMsg_SayText.chat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='textallchat', full_name='CCSUsrMsg_SayText.textallchat', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=498,
)


_CCSUSRMSG_SAYTEXT2 = _descriptor.Descriptor(
  name='CCSUsrMsg_SayText2',
  full_name='CCSUsrMsg_SayText2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ent_idx', full_name='CCSUsrMsg_SayText2.ent_idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='chat', full_name='CCSUsrMsg_SayText2.chat', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_name', full_name='CCSUsrMsg_SayText2.msg_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='params', full_name='CCSUsrMsg_SayText2.params', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='textallchat', full_name='CCSUsrMsg_SayText2.textallchat', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=606,
)


_CCSUSRMSG_TEXTMSG = _descriptor.Descriptor(
  name='CCSUsrMsg_TextMsg',
  full_name='CCSUsrMsg_TextMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_dst', full_name='CCSUsrMsg_TextMsg.msg_dst', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='params', full_name='CCSUsrMsg_TextMsg.params', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=660,
)


_CCSUSRMSG_HUDMSG = _descriptor.Descriptor(
  name='CCSUsrMsg_HudMsg',
  full_name='CCSUsrMsg_HudMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='CCSUsrMsg_HudMsg.channel', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos', full_name='CCSUsrMsg_HudMsg.pos', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clr1', full_name='CCSUsrMsg_HudMsg.clr1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clr2', full_name='CCSUsrMsg_HudMsg.clr2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='effect', full_name='CCSUsrMsg_HudMsg.effect', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fade_in_time', full_name='CCSUsrMsg_HudMsg.fade_in_time', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fade_out_time', full_name='CCSUsrMsg_HudMsg.fade_out_time', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hold_time', full_name='CCSUsrMsg_HudMsg.hold_time', index=7,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fx_time', full_name='CCSUsrMsg_HudMsg.fx_time', index=8,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='CCSUsrMsg_HudMsg.text', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=663,
  serialized_end=887,
)


_CCSUSRMSG_SHAKE = _descriptor.Descriptor(
  name='CCSUsrMsg_Shake',
  full_name='CCSUsrMsg_Shake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='CCSUsrMsg_Shake.command', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='local_amplitude', full_name='CCSUsrMsg_Shake.local_amplitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='CCSUsrMsg_Shake.frequency', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CCSUsrMsg_Shake.duration', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=889,
  serialized_end=985,
)


_CCSUSRMSG_FADE = _descriptor.Descriptor(
  name='CCSUsrMsg_Fade',
  full_name='CCSUsrMsg_Fade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='CCSUsrMsg_Fade.duration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hold_time', full_name='CCSUsrMsg_Fade.hold_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CCSUsrMsg_Fade.flags', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clr', full_name='CCSUsrMsg_Fade.clr', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1079,
)


_CCSUSRMSG_RUMBLE = _descriptor.Descriptor(
  name='CCSUsrMsg_Rumble',
  full_name='CCSUsrMsg_Rumble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='CCSUsrMsg_Rumble.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='CCSUsrMsg_Rumble.data', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CCSUsrMsg_Rumble.flags', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1143,
)


_CCSUSRMSG_CLOSECAPTION = _descriptor.Descriptor(
  name='CCSUsrMsg_CloseCaption',
  full_name='CCSUsrMsg_CloseCaption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='CCSUsrMsg_CloseCaption.hash', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CCSUsrMsg_CloseCaption.duration', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_player', full_name='CCSUsrMsg_CloseCaption.from_player', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1145,
  serialized_end=1222,
)


_CCSUSRMSG_CLOSECAPTIONDIRECT = _descriptor.Descriptor(
  name='CCSUsrMsg_CloseCaptionDirect',
  full_name='CCSUsrMsg_CloseCaptionDirect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='CCSUsrMsg_CloseCaptionDirect.hash', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CCSUsrMsg_CloseCaptionDirect.duration', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_player', full_name='CCSUsrMsg_CloseCaptionDirect.from_player', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1307,
)


_CCSUSRMSG_SENDAUDIO = _descriptor.Descriptor(
  name='CCSUsrMsg_SendAudio',
  full_name='CCSUsrMsg_SendAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='radio_sound', full_name='CCSUsrMsg_SendAudio.radio_sound', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1351,
)


_CCSUSRMSG_RAWAUDIO = _descriptor.Descriptor(
  name='CCSUsrMsg_RawAudio',
  full_name='CCSUsrMsg_RawAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pitch', full_name='CCSUsrMsg_RawAudio.pitch', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entidx', full_name='CCSUsrMsg_RawAudio.entidx', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='CCSUsrMsg_RawAudio.duration', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice_filename', full_name='CCSUsrMsg_RawAudio.voice_filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1446,
)


_CCSUSRMSG_VOICEMASK_PLAYERMASK = _descriptor.Descriptor(
  name='PlayerMask',
  full_name='CCSUsrMsg_VoiceMask.PlayerMask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_rules_mask', full_name='CCSUsrMsg_VoiceMask.PlayerMask.game_rules_mask', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ban_masks', full_name='CCSUsrMsg_VoiceMask.PlayerMask.ban_masks', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1610,
)

_CCSUSRMSG_VOICEMASK = _descriptor.Descriptor(
  name='CCSUsrMsg_VoiceMask',
  full_name='CCSUsrMsg_VoiceMask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_masks', full_name='CCSUsrMsg_VoiceMask.player_masks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_mod_enable', full_name='CCSUsrMsg_VoiceMask.player_mod_enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CCSUSRMSG_VOICEMASK_PLAYERMASK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1610,
)


_CCSUSRMSG_DAMAGE = _descriptor.Descriptor(
  name='CCSUsrMsg_Damage',
  full_name='CCSUsrMsg_Damage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='CCSUsrMsg_Damage.amount', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inflictor_world_pos', full_name='CCSUsrMsg_Damage.inflictor_world_pos', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='victim_entindex', full_name='CCSUsrMsg_Damage.victim_entindex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1713,
)


_CCSUSRMSG_RADIOTEXT = _descriptor.Descriptor(
  name='CCSUsrMsg_RadioText',
  full_name='CCSUsrMsg_RadioText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_dst', full_name='CCSUsrMsg_RadioText.msg_dst', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client', full_name='CCSUsrMsg_RadioText.client', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_name', full_name='CCSUsrMsg_RadioText.msg_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='params', full_name='CCSUsrMsg_RadioText.params', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1715,
  serialized_end=1803,
)


_CCSUSRMSG_HINTTEXT = _descriptor.Descriptor(
  name='CCSUsrMsg_HintText',
  full_name='CCSUsrMsg_HintText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='CCSUsrMsg_HintText.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1839,
)


_CCSUSRMSG_KEYHINTTEXT = _descriptor.Descriptor(
  name='CCSUsrMsg_KeyHintText',
  full_name='CCSUsrMsg_KeyHintText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hints', full_name='CCSUsrMsg_KeyHintText.hints', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1841,
  serialized_end=1879,
)


_CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE_SPOTTEDENTITYUPDATE = _descriptor.Descriptor(
  name='SpottedEntityUpdate',
  full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_idx', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.entity_idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_id', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.class_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_x', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.origin_x', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_y', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.origin_y', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_z', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.origin_z', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle_y', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.angle_y', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='defuser', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.defuser', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_has_defuser', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.player_has_defuser', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='player_has_c4', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate.player_has_c4', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2224,
)

_CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE = _descriptor.Descriptor(
  name='CCSUsrMsg_ProcessSpottedEntityUpdate',
  full_name='CCSUsrMsg_ProcessSpottedEntityUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_update', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.new_update', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entity_updates', full_name='CCSUsrMsg_ProcessSpottedEntityUpdate.entity_updates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE_SPOTTEDENTITYUPDATE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=2224,
)


_CCSUSRMSG_SENDPLAYERITEMDROPS = _descriptor.Descriptor(
  name='CCSUsrMsg_SendPlayerItemDrops',
  full_name='CCSUsrMsg_SendPlayerItemDrops',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_updates', full_name='CCSUsrMsg_SendPlayerItemDrops.entity_updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2226,
  serialized_end=2309,
)


_CCSUSRMSG_SENDPLAYERITEMFOUND = _descriptor.Descriptor(
  name='CCSUsrMsg_SendPlayerItemFound',
  full_name='CCSUsrMsg_SendPlayerItemFound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iteminfo', full_name='CCSUsrMsg_SendPlayerItemFound.iteminfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entindex', full_name='CCSUsrMsg_SendPlayerItemFound.entindex', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2311,
  serialized_end=2406,
)


_CCSUSRMSG_RELOADEFFECT = _descriptor.Descriptor(
  name='CCSUsrMsg_ReloadEffect',
  full_name='CCSUsrMsg_ReloadEffect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entidx', full_name='CCSUsrMsg_ReloadEffect.entidx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='actanim', full_name='CCSUsrMsg_ReloadEffect.actanim', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_x', full_name='CCSUsrMsg_ReloadEffect.origin_x', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_y', full_name='CCSUsrMsg_ReloadEffect.origin_y', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin_z', full_name='CCSUsrMsg_ReloadEffect.origin_z', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2408,
  serialized_end=2519,
)


_CCSUSRMSG_ADJUSTMONEY = _descriptor.Descriptor(
  name='CCSUsrMsg_AdjustMoney',
  full_name='CCSUsrMsg_AdjustMoney',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='CCSUsrMsg_AdjustMoney.amount', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2521,
  serialized_end=2560,
)


_CCSUSRMSG_REPORTHIT = _descriptor.Descriptor(
  name='CCSUsrMsg_ReportHit',
  full_name='CCSUsrMsg_ReportHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pos_x', full_name='CCSUsrMsg_ReportHit.pos_x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos_y', full_name='CCSUsrMsg_ReportHit.pos_y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CCSUsrMsg_ReportHit.timestamp', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos_z', full_name='CCSUsrMsg_ReportHit.pos_z', index=3,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2562,
  serialized_end=2647,
)


_CCSUSRMSG_KILLCAM = _descriptor.Descriptor(
  name='CCSUsrMsg_KillCam',
  full_name='CCSUsrMsg_KillCam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='obs_mode', full_name='CCSUsrMsg_KillCam.obs_mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_target', full_name='CCSUsrMsg_KillCam.first_target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_target', full_name='CCSUsrMsg_KillCam.second_target', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=2731,
)


_CCSUSRMSG_DESIREDTIMESCALE = _descriptor.Descriptor(
  name='CCSUsrMsg_DesiredTimescale',
  full_name='CCSUsrMsg_DesiredTimescale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desired_timescale', full_name='CCSUsrMsg_DesiredTimescale.desired_timescale', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_realtime_sec', full_name='CCSUsrMsg_DesiredTimescale.duration_realtime_sec', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interpolator_type', full_name='CCSUsrMsg_DesiredTimescale.interpolator_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_blend_time', full_name='CCSUsrMsg_DesiredTimescale.start_blend_time', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2734,
  serialized_end=2873,
)


_CCSUSRMSG_CURRENTTIMESCALE = _descriptor.Descriptor(
  name='CCSUsrMsg_CurrentTimescale',
  full_name='CCSUsrMsg_CurrentTimescale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cur_timescale', full_name='CCSUsrMsg_CurrentTimescale.cur_timescale', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2875,
  serialized_end=2926,
)


_CCSUSRMSG_ACHIEVEMENTEVENT = _descriptor.Descriptor(
  name='CCSUsrMsg_AchievementEvent',
  full_name='CCSUsrMsg_AchievementEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievement', full_name='CCSUsrMsg_AchievementEvent.achievement', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='CCSUsrMsg_AchievementEvent.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='CCSUsrMsg_AchievementEvent.user_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2928,
  serialized_end=3009,
)


_CCSUSRMSG_MATCHENDCONDITIONS = _descriptor.Descriptor(
  name='CCSUsrMsg_MatchEndConditions',
  full_name='CCSUsrMsg_MatchEndConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fraglimit', full_name='CCSUsrMsg_MatchEndConditions.fraglimit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mp_maxrounds', full_name='CCSUsrMsg_MatchEndConditions.mp_maxrounds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mp_winlimit', full_name='CCSUsrMsg_MatchEndConditions.mp_winlimit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mp_timelimit', full_name='CCSUsrMsg_MatchEndConditions.mp_timelimit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3011,
  serialized_end=3125,
)


_CCSUSRMSG_PLAYERSTATSUPDATE_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='CCSUsrMsg_PlayerStatsUpdate.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='CCSUsrMsg_PlayerStatsUpdate.Stat.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delta', full_name='CCSUsrMsg_PlayerStatsUpdate.Stat.delta', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3256,
  serialized_end=3290,
)

_CCSUSRMSG_PLAYERSTATSUPDATE = _descriptor.Descriptor(
  name='CCSUsrMsg_PlayerStatsUpdate',
  full_name='CCSUsrMsg_PlayerStatsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='CCSUsrMsg_PlayerStatsUpdate.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='CCSUsrMsg_PlayerStatsUpdate.stats', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='CCSUsrMsg_PlayerStatsUpdate.user_id', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='crc', full_name='CCSUsrMsg_PlayerStatsUpdate.crc', index=3,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CCSUSRMSG_PLAYERSTATSUPDATE_STAT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3128,
  serialized_end=3290,
)


_CCSUSRMSG_DISPLAYINVENTORY = _descriptor.Descriptor(
  name='CCSUsrMsg_DisplayInventory',
  full_name='CCSUsrMsg_DisplayInventory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='display', full_name='CCSUsrMsg_DisplayInventory.display', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='CCSUsrMsg_DisplayInventory.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3292,
  serialized_end=3354,
)


_CCSUSRMSG_QUESTPROGRESS = _descriptor.Descriptor(
  name='CCSUsrMsg_QuestProgress',
  full_name='CCSUsrMsg_QuestProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quest_id', full_name='CCSUsrMsg_QuestProgress.quest_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal_points', full_name='CCSUsrMsg_QuestProgress.normal_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus_points', full_name='CCSUsrMsg_QuestProgress.bonus_points', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_event_quest', full_name='CCSUsrMsg_QuestProgress.is_event_quest', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3356,
  serialized_end=3468,
)


_CCSUSRMSG_SCORELEADERBOARDDATA = _descriptor.Descriptor(
  name='CCSUsrMsg_ScoreLeaderboardData',
  full_name='CCSUsrMsg_ScoreLeaderboardData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CCSUsrMsg_ScoreLeaderboardData.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3470,
  serialized_end=3539,
)


_CCSUSRMSG_PLAYERDECALDIGITALSIGNATURE = _descriptor.Descriptor(
  name='CCSUsrMsg_PlayerDecalDigitalSignature',
  full_name='CCSUsrMsg_PlayerDecalDigitalSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CCSUsrMsg_PlayerDecalDigitalSignature.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3541,
  serialized_end=3624,
)


_CCSUSRMSG_XRANKGET = _descriptor.Descriptor(
  name='CCSUsrMsg_XRankGet',
  full_name='CCSUsrMsg_XRankGet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode_idx', full_name='CCSUsrMsg_XRankGet.mode_idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='controller', full_name='CCSUsrMsg_XRankGet.controller', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3626,
  serialized_end=3684,
)


_CCSUSRMSG_XRANKUPD = _descriptor.Descriptor(
  name='CCSUsrMsg_XRankUpd',
  full_name='CCSUsrMsg_XRankUpd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode_idx', full_name='CCSUsrMsg_XRankUpd.mode_idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='controller', full_name='CCSUsrMsg_XRankUpd.controller', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ranking', full_name='CCSUsrMsg_XRankUpd.ranking', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3686,
  serialized_end=3761,
)


_CCSUSRMSG_CALLVOTEFAILED = _descriptor.Descriptor(
  name='CCSUsrMsg_CallVoteFailed',
  full_name='CCSUsrMsg_CallVoteFailed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='CCSUsrMsg_CallVoteFailed.reason', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='CCSUsrMsg_CallVoteFailed.time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3763,
  serialized_end=3819,
)


_CCSUSRMSG_VOTESTART = _descriptor.Descriptor(
  name='CCSUsrMsg_VoteStart',
  full_name='CCSUsrMsg_VoteStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CCSUsrMsg_VoteStart.team', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ent_idx', full_name='CCSUsrMsg_VoteStart.ent_idx', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_type', full_name='CCSUsrMsg_VoteStart.vote_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disp_str', full_name='CCSUsrMsg_VoteStart.disp_str', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details_str', full_name='CCSUsrMsg_VoteStart.details_str', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='other_team_str', full_name='CCSUsrMsg_VoteStart.other_team_str', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_yes_no_vote', full_name='CCSUsrMsg_VoteStart.is_yes_no_vote', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3822,
  serialized_end=3980,
)


_CCSUSRMSG_VOTEPASS = _descriptor.Descriptor(
  name='CCSUsrMsg_VotePass',
  full_name='CCSUsrMsg_VotePass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CCSUsrMsg_VotePass.team', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vote_type', full_name='CCSUsrMsg_VotePass.vote_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disp_str', full_name='CCSUsrMsg_VotePass.disp_str', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='details_str', full_name='CCSUsrMsg_VotePass.details_str', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3982,
  serialized_end=4074,
)


_CCSUSRMSG_VOTEFAILED = _descriptor.Descriptor(
  name='CCSUsrMsg_VoteFailed',
  full_name='CCSUsrMsg_VoteFailed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CCSUsrMsg_VoteFailed.team', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='CCSUsrMsg_VoteFailed.reason', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4076,
  serialized_end=4128,
)


_CCSUSRMSG_VOTESETUP = _descriptor.Descriptor(
  name='CCSUsrMsg_VoteSetup',
  full_name='CCSUsrMsg_VoteSetup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='potential_issues', full_name='CCSUsrMsg_VoteSetup.potential_issues', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4130,
  serialized_end=4177,
)


_CCSUSRMSG_SENDLASTKILLERDAMAGETOCLIENT = _descriptor.Descriptor(
  name='CCSUsrMsg_SendLastKillerDamageToClient',
  full_name='CCSUsrMsg_SendLastKillerDamageToClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_hits_given', full_name='CCSUsrMsg_SendLastKillerDamageToClient.num_hits_given', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage_given', full_name='CCSUsrMsg_SendLastKillerDamageToClient.damage_given', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_hits_taken', full_name='CCSUsrMsg_SendLastKillerDamageToClient.num_hits_taken', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='damage_taken', full_name='CCSUsrMsg_SendLastKillerDamageToClient.damage_taken', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4180,
  serialized_end=4312,
)


_CCSUSRMSG_SERVERRANKUPDATE_RANKUPDATE = _descriptor.Descriptor(
  name='RankUpdate',
  full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate.account_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_old', full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate.rank_old', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_new', full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate.rank_new', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_wins', full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate.num_wins', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rank_change', full_name='CCSUsrMsg_ServerRankUpdate.RankUpdate.rank_change', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4406,
  serialized_end=4513,
)

_CCSUSRMSG_SERVERRANKUPDATE = _descriptor.Descriptor(
  name='CCSUsrMsg_ServerRankUpdate',
  full_name='CCSUsrMsg_ServerRankUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank_update', full_name='CCSUsrMsg_ServerRankUpdate.rank_update', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CCSUSRMSG_SERVERRANKUPDATE_RANKUPDATE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4315,
  serialized_end=4513,
)


_CCSUSRMSG_XPUPDATE = _descriptor.Descriptor(
  name='CCSUsrMsg_XpUpdate',
  full_name='CCSUsrMsg_XpUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='CCSUsrMsg_XpUpdate.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4515,
  serialized_end=4596,
)


_CCSUSRMSG_ITEMPICKUP = _descriptor.Descriptor(
  name='CCSUsrMsg_ItemPickup',
  full_name='CCSUsrMsg_ItemPickup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='CCSUsrMsg_ItemPickup.item', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4598,
  serialized_end=4634,
)


_CCSUSRMSG_SHOWMENU = _descriptor.Descriptor(
  name='CCSUsrMsg_ShowMenu',
  full_name='CCSUsrMsg_ShowMenu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bits_valid_slots', full_name='CCSUsrMsg_ShowMenu.bits_valid_slots', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='display_time', full_name='CCSUsrMsg_ShowMenu.display_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='menu_string', full_name='CCSUsrMsg_ShowMenu.menu_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4636,
  serialized_end=4725,
)


_CCSUSRMSG_BARTIME = _descriptor.Descriptor(
  name='CCSUsrMsg_BarTime',
  full_name='CCSUsrMsg_BarTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='CCSUsrMsg_BarTime.time', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4727,
  serialized_end=4760,
)


_CCSUSRMSG_AMMODENIED = _descriptor.Descriptor(
  name='CCSUsrMsg_AmmoDenied',
  full_name='CCSUsrMsg_AmmoDenied',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ammoIdx', full_name='CCSUsrMsg_AmmoDenied.ammoIdx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4762,
  serialized_end=4801,
)


_CCSUSRMSG_MARKACHIEVEMENT = _descriptor.Descriptor(
  name='CCSUsrMsg_MarkAchievement',
  full_name='CCSUsrMsg_MarkAchievement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='achievement', full_name='CCSUsrMsg_MarkAchievement.achievement', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4803,
  serialized_end=4851,
)


_CCSUSRMSG_MATCHSTATSUPDATE = _descriptor.Descriptor(
  name='CCSUsrMsg_MatchStatsUpdate',
  full_name='CCSUsrMsg_MatchStatsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='CCSUsrMsg_MatchStatsUpdate.update', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4853,
  serialized_end=4897,
)


_CCSUSRMSG_ITEMDROP = _descriptor.Descriptor(
  name='CCSUsrMsg_ItemDrop',
  full_name='CCSUsrMsg_ItemDrop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CCSUsrMsg_ItemDrop.itemid', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='death', full_name='CCSUsrMsg_ItemDrop.death', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4899,
  serialized_end=4950,
)


_CCSUSRMSG_GLOWPROPTURNOFF = _descriptor.Descriptor(
  name='CCSUsrMsg_GlowPropTurnOff',
  full_name='CCSUsrMsg_GlowPropTurnOff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entidx', full_name='CCSUsrMsg_GlowPropTurnOff.entidx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4952,
  serialized_end=4995,
)


_CCSUSRMSG_ROUNDBACKUPFILENAMES = _descriptor.Descriptor(
  name='CCSUsrMsg_RoundBackupFilenames',
  full_name='CCSUsrMsg_RoundBackupFilenames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='CCSUsrMsg_RoundBackupFilenames.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='index', full_name='CCSUsrMsg_RoundBackupFilenames.index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CCSUsrMsg_RoundBackupFilenames.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nicename', full_name='CCSUsrMsg_RoundBackupFilenames.nicename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4997,
  serialized_end=5095,
)


_CCSUSRMSG_RESETHUD = _descriptor.Descriptor(
  name='CCSUsrMsg_ResetHud',
  full_name='CCSUsrMsg_ResetHud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reset', full_name='CCSUsrMsg_ResetHud.reset', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5097,
  serialized_end=5132,
)


_CCSUSRMSG_GAMETITLE = _descriptor.Descriptor(
  name='CCSUsrMsg_GameTitle',
  full_name='CCSUsrMsg_GameTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_GameTitle.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5134,
  serialized_end=5170,
)


_CCSUSRMSG_REQUESTSTATE = _descriptor.Descriptor(
  name='CCSUsrMsg_RequestState',
  full_name='CCSUsrMsg_RequestState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_RequestState.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5172,
  serialized_end=5211,
)


_CCSUSRMSG_STOPSPECTATORMODE = _descriptor.Descriptor(
  name='CCSUsrMsg_StopSpectatorMode',
  full_name='CCSUsrMsg_StopSpectatorMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_StopSpectatorMode.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5213,
  serialized_end=5257,
)


_CCSUSRMSG_DISCONNECTTOLOBBY = _descriptor.Descriptor(
  name='CCSUsrMsg_DisconnectToLobby',
  full_name='CCSUsrMsg_DisconnectToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_DisconnectToLobby.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5259,
  serialized_end=5303,
)


_CCSUSRMSG_WARMUPHASENDED = _descriptor.Descriptor(
  name='CCSUsrMsg_WarmupHasEnded',
  full_name='CCSUsrMsg_WarmupHasEnded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_WarmupHasEnded.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5305,
  serialized_end=5346,
)


_CCSUSRMSG_CLIENTINFO = _descriptor.Descriptor(
  name='CCSUsrMsg_ClientInfo',
  full_name='CCSUsrMsg_ClientInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dummy', full_name='CCSUsrMsg_ClientInfo.dummy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5348,
  serialized_end=5385,
)


_CCSUSRMSG_SERVERRANKREVEALALL = _descriptor.Descriptor(
  name='CCSUsrMsg_ServerRankRevealAll',
  full_name='CCSUsrMsg_ServerRankRevealAll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds_till_shutdown', full_name='CCSUsrMsg_ServerRankRevealAll.seconds_till_shutdown', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5387,
  serialized_end=5449,
)

_CCSUSRMSG_VGUIMENU_SUBKEY.containing_type = _CCSUSRMSG_VGUIMENU
_CCSUSRMSG_VGUIMENU.fields_by_name['subkeys'].message_type = _CCSUSRMSG_VGUIMENU_SUBKEY
_CCSUSRMSG_HUDMSG.fields_by_name['pos'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGVECTOR2D
_CCSUSRMSG_HUDMSG.fields_by_name['clr1'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGRGBA
_CCSUSRMSG_HUDMSG.fields_by_name['clr2'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGRGBA
_CCSUSRMSG_FADE.fields_by_name['clr'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGRGBA
_CCSUSRMSG_VOICEMASK_PLAYERMASK.containing_type = _CCSUSRMSG_VOICEMASK
_CCSUSRMSG_VOICEMASK.fields_by_name['player_masks'].message_type = _CCSUSRMSG_VOICEMASK_PLAYERMASK
_CCSUSRMSG_DAMAGE.fields_by_name['inflictor_world_pos'].message_type = demoparser_dot_protobufs_dot_netmessages__pb2._CMSGVECTOR
_CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE_SPOTTEDENTITYUPDATE.containing_type = _CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE
_CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE.fields_by_name['entity_updates'].message_type = _CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE_SPOTTEDENTITYUPDATE
_CCSUSRMSG_SENDPLAYERITEMDROPS.fields_by_name['entity_updates'].message_type = demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2._CECONITEMPREVIEWDATABLOCK
_CCSUSRMSG_SENDPLAYERITEMFOUND.fields_by_name['iteminfo'].message_type = demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2._CECONITEMPREVIEWDATABLOCK
_CCSUSRMSG_PLAYERSTATSUPDATE_STAT.containing_type = _CCSUSRMSG_PLAYERSTATSUPDATE
_CCSUSRMSG_PLAYERSTATSUPDATE.fields_by_name['stats'].message_type = _CCSUSRMSG_PLAYERSTATSUPDATE_STAT
_CCSUSRMSG_SCORELEADERBOARDDATA.fields_by_name['data'].message_type = demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2._SCORELEADERBOARDDATA
_CCSUSRMSG_PLAYERDECALDIGITALSIGNATURE.fields_by_name['data'].message_type = demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2._PLAYERDECALDIGITALSIGNATURE
_CCSUSRMSG_SERVERRANKUPDATE_RANKUPDATE.containing_type = _CCSUSRMSG_SERVERRANKUPDATE
_CCSUSRMSG_SERVERRANKUPDATE.fields_by_name['rank_update'].message_type = _CCSUSRMSG_SERVERRANKUPDATE_RANKUPDATE
_CCSUSRMSG_XPUPDATE.fields_by_name['data'].message_type = demoparser_dot_protobufs_dot_cstrike15__gcmessages__pb2._CMSGGCCSTRIKE15_V2_GC2SERVERNOTIFYXPREWARDED
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VGUIMenu'] = _CCSUSRMSG_VGUIMENU
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Geiger'] = _CCSUSRMSG_GEIGER
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Train'] = _CCSUSRMSG_TRAIN
DESCRIPTOR.message_types_by_name['CCSUsrMsg_HudText'] = _CCSUSRMSG_HUDTEXT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SayText'] = _CCSUSRMSG_SAYTEXT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SayText2'] = _CCSUSRMSG_SAYTEXT2
DESCRIPTOR.message_types_by_name['CCSUsrMsg_TextMsg'] = _CCSUSRMSG_TEXTMSG
DESCRIPTOR.message_types_by_name['CCSUsrMsg_HudMsg'] = _CCSUSRMSG_HUDMSG
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Shake'] = _CCSUSRMSG_SHAKE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Fade'] = _CCSUSRMSG_FADE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Rumble'] = _CCSUSRMSG_RUMBLE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_CloseCaption'] = _CCSUSRMSG_CLOSECAPTION
DESCRIPTOR.message_types_by_name['CCSUsrMsg_CloseCaptionDirect'] = _CCSUSRMSG_CLOSECAPTIONDIRECT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SendAudio'] = _CCSUSRMSG_SENDAUDIO
DESCRIPTOR.message_types_by_name['CCSUsrMsg_RawAudio'] = _CCSUSRMSG_RAWAUDIO
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VoiceMask'] = _CCSUSRMSG_VOICEMASK
DESCRIPTOR.message_types_by_name['CCSUsrMsg_Damage'] = _CCSUSRMSG_DAMAGE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_RadioText'] = _CCSUSRMSG_RADIOTEXT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_HintText'] = _CCSUSRMSG_HINTTEXT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_KeyHintText'] = _CCSUSRMSG_KEYHINTTEXT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ProcessSpottedEntityUpdate'] = _CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SendPlayerItemDrops'] = _CCSUSRMSG_SENDPLAYERITEMDROPS
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SendPlayerItemFound'] = _CCSUSRMSG_SENDPLAYERITEMFOUND
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ReloadEffect'] = _CCSUSRMSG_RELOADEFFECT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_AdjustMoney'] = _CCSUSRMSG_ADJUSTMONEY
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ReportHit'] = _CCSUSRMSG_REPORTHIT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_KillCam'] = _CCSUSRMSG_KILLCAM
DESCRIPTOR.message_types_by_name['CCSUsrMsg_DesiredTimescale'] = _CCSUSRMSG_DESIREDTIMESCALE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_CurrentTimescale'] = _CCSUSRMSG_CURRENTTIMESCALE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_AchievementEvent'] = _CCSUSRMSG_ACHIEVEMENTEVENT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_MatchEndConditions'] = _CCSUSRMSG_MATCHENDCONDITIONS
DESCRIPTOR.message_types_by_name['CCSUsrMsg_PlayerStatsUpdate'] = _CCSUSRMSG_PLAYERSTATSUPDATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_DisplayInventory'] = _CCSUSRMSG_DISPLAYINVENTORY
DESCRIPTOR.message_types_by_name['CCSUsrMsg_QuestProgress'] = _CCSUSRMSG_QUESTPROGRESS
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ScoreLeaderboardData'] = _CCSUSRMSG_SCORELEADERBOARDDATA
DESCRIPTOR.message_types_by_name['CCSUsrMsg_PlayerDecalDigitalSignature'] = _CCSUSRMSG_PLAYERDECALDIGITALSIGNATURE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_XRankGet'] = _CCSUSRMSG_XRANKGET
DESCRIPTOR.message_types_by_name['CCSUsrMsg_XRankUpd'] = _CCSUSRMSG_XRANKUPD
DESCRIPTOR.message_types_by_name['CCSUsrMsg_CallVoteFailed'] = _CCSUSRMSG_CALLVOTEFAILED
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VoteStart'] = _CCSUSRMSG_VOTESTART
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VotePass'] = _CCSUSRMSG_VOTEPASS
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VoteFailed'] = _CCSUSRMSG_VOTEFAILED
DESCRIPTOR.message_types_by_name['CCSUsrMsg_VoteSetup'] = _CCSUSRMSG_VOTESETUP
DESCRIPTOR.message_types_by_name['CCSUsrMsg_SendLastKillerDamageToClient'] = _CCSUSRMSG_SENDLASTKILLERDAMAGETOCLIENT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ServerRankUpdate'] = _CCSUSRMSG_SERVERRANKUPDATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_XpUpdate'] = _CCSUSRMSG_XPUPDATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ItemPickup'] = _CCSUSRMSG_ITEMPICKUP
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ShowMenu'] = _CCSUSRMSG_SHOWMENU
DESCRIPTOR.message_types_by_name['CCSUsrMsg_BarTime'] = _CCSUSRMSG_BARTIME
DESCRIPTOR.message_types_by_name['CCSUsrMsg_AmmoDenied'] = _CCSUSRMSG_AMMODENIED
DESCRIPTOR.message_types_by_name['CCSUsrMsg_MarkAchievement'] = _CCSUSRMSG_MARKACHIEVEMENT
DESCRIPTOR.message_types_by_name['CCSUsrMsg_MatchStatsUpdate'] = _CCSUSRMSG_MATCHSTATSUPDATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ItemDrop'] = _CCSUSRMSG_ITEMDROP
DESCRIPTOR.message_types_by_name['CCSUsrMsg_GlowPropTurnOff'] = _CCSUSRMSG_GLOWPROPTURNOFF
DESCRIPTOR.message_types_by_name['CCSUsrMsg_RoundBackupFilenames'] = _CCSUSRMSG_ROUNDBACKUPFILENAMES
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ResetHud'] = _CCSUSRMSG_RESETHUD
DESCRIPTOR.message_types_by_name['CCSUsrMsg_GameTitle'] = _CCSUSRMSG_GAMETITLE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_RequestState'] = _CCSUSRMSG_REQUESTSTATE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_StopSpectatorMode'] = _CCSUSRMSG_STOPSPECTATORMODE
DESCRIPTOR.message_types_by_name['CCSUsrMsg_DisconnectToLobby'] = _CCSUSRMSG_DISCONNECTTOLOBBY
DESCRIPTOR.message_types_by_name['CCSUsrMsg_WarmupHasEnded'] = _CCSUSRMSG_WARMUPHASENDED
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ClientInfo'] = _CCSUSRMSG_CLIENTINFO
DESCRIPTOR.message_types_by_name['CCSUsrMsg_ServerRankRevealAll'] = _CCSUSRMSG_SERVERRANKREVEALALL
DESCRIPTOR.enum_types_by_name['ECstrike15UserMessages'] = _ECSTRIKE15USERMESSAGES

CCSUsrMsg_VGUIMenu = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VGUIMenu', (_message.Message,), dict(

  Subkey = _reflection.GeneratedProtocolMessageType('Subkey', (_message.Message,), dict(
    DESCRIPTOR = _CCSUSRMSG_VGUIMENU_SUBKEY,
    __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
    # @@protoc_insertion_point(class_scope:CCSUsrMsg_VGUIMenu.Subkey)
    ))
  ,
  DESCRIPTOR = _CCSUSRMSG_VGUIMENU,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VGUIMenu)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VGUIMenu)
_sym_db.RegisterMessage(CCSUsrMsg_VGUIMenu.Subkey)

CCSUsrMsg_Geiger = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Geiger', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_GEIGER,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Geiger)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Geiger)

CCSUsrMsg_Train = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Train', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_TRAIN,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Train)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Train)

CCSUsrMsg_HudText = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_HudText', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_HUDTEXT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_HudText)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_HudText)

CCSUsrMsg_SayText = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SayText', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SAYTEXT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SayText)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SayText)

CCSUsrMsg_SayText2 = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SayText2', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SAYTEXT2,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SayText2)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SayText2)

CCSUsrMsg_TextMsg = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_TextMsg', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_TEXTMSG,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_TextMsg)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_TextMsg)

CCSUsrMsg_HudMsg = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_HudMsg', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_HUDMSG,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_HudMsg)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_HudMsg)

CCSUsrMsg_Shake = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Shake', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SHAKE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Shake)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Shake)

CCSUsrMsg_Fade = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Fade', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_FADE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Fade)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Fade)

CCSUsrMsg_Rumble = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Rumble', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_RUMBLE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Rumble)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Rumble)

CCSUsrMsg_CloseCaption = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_CloseCaption', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_CLOSECAPTION,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_CloseCaption)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_CloseCaption)

CCSUsrMsg_CloseCaptionDirect = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_CloseCaptionDirect', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_CLOSECAPTIONDIRECT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_CloseCaptionDirect)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_CloseCaptionDirect)

CCSUsrMsg_SendAudio = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SendAudio', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SENDAUDIO,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SendAudio)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SendAudio)

CCSUsrMsg_RawAudio = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_RawAudio', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_RAWAUDIO,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_RawAudio)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_RawAudio)

CCSUsrMsg_VoiceMask = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VoiceMask', (_message.Message,), dict(

  PlayerMask = _reflection.GeneratedProtocolMessageType('PlayerMask', (_message.Message,), dict(
    DESCRIPTOR = _CCSUSRMSG_VOICEMASK_PLAYERMASK,
    __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
    # @@protoc_insertion_point(class_scope:CCSUsrMsg_VoiceMask.PlayerMask)
    ))
  ,
  DESCRIPTOR = _CCSUSRMSG_VOICEMASK,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VoiceMask)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VoiceMask)
_sym_db.RegisterMessage(CCSUsrMsg_VoiceMask.PlayerMask)

CCSUsrMsg_Damage = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_Damage', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_DAMAGE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_Damage)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_Damage)

CCSUsrMsg_RadioText = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_RadioText', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_RADIOTEXT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_RadioText)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_RadioText)

CCSUsrMsg_HintText = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_HintText', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_HINTTEXT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_HintText)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_HintText)

CCSUsrMsg_KeyHintText = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_KeyHintText', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_KEYHINTTEXT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_KeyHintText)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_KeyHintText)

CCSUsrMsg_ProcessSpottedEntityUpdate = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ProcessSpottedEntityUpdate', (_message.Message,), dict(

  SpottedEntityUpdate = _reflection.GeneratedProtocolMessageType('SpottedEntityUpdate', (_message.Message,), dict(
    DESCRIPTOR = _CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE_SPOTTEDENTITYUPDATE,
    __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
    # @@protoc_insertion_point(class_scope:CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate)
    ))
  ,
  DESCRIPTOR = _CCSUSRMSG_PROCESSSPOTTEDENTITYUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ProcessSpottedEntityUpdate)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ProcessSpottedEntityUpdate)
_sym_db.RegisterMessage(CCSUsrMsg_ProcessSpottedEntityUpdate.SpottedEntityUpdate)

CCSUsrMsg_SendPlayerItemDrops = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SendPlayerItemDrops', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SENDPLAYERITEMDROPS,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SendPlayerItemDrops)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SendPlayerItemDrops)

CCSUsrMsg_SendPlayerItemFound = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SendPlayerItemFound', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SENDPLAYERITEMFOUND,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SendPlayerItemFound)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SendPlayerItemFound)

CCSUsrMsg_ReloadEffect = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ReloadEffect', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_RELOADEFFECT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ReloadEffect)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ReloadEffect)

CCSUsrMsg_AdjustMoney = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_AdjustMoney', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_ADJUSTMONEY,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_AdjustMoney)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_AdjustMoney)

CCSUsrMsg_ReportHit = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ReportHit', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_REPORTHIT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ReportHit)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ReportHit)

CCSUsrMsg_KillCam = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_KillCam', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_KILLCAM,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_KillCam)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_KillCam)

CCSUsrMsg_DesiredTimescale = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_DesiredTimescale', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_DESIREDTIMESCALE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_DesiredTimescale)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_DesiredTimescale)

CCSUsrMsg_CurrentTimescale = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_CurrentTimescale', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_CURRENTTIMESCALE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_CurrentTimescale)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_CurrentTimescale)

CCSUsrMsg_AchievementEvent = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_AchievementEvent', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_ACHIEVEMENTEVENT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_AchievementEvent)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_AchievementEvent)

CCSUsrMsg_MatchEndConditions = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_MatchEndConditions', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_MATCHENDCONDITIONS,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_MatchEndConditions)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_MatchEndConditions)

CCSUsrMsg_PlayerStatsUpdate = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_PlayerStatsUpdate', (_message.Message,), dict(

  Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), dict(
    DESCRIPTOR = _CCSUSRMSG_PLAYERSTATSUPDATE_STAT,
    __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
    # @@protoc_insertion_point(class_scope:CCSUsrMsg_PlayerStatsUpdate.Stat)
    ))
  ,
  DESCRIPTOR = _CCSUSRMSG_PLAYERSTATSUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_PlayerStatsUpdate)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_PlayerStatsUpdate)
_sym_db.RegisterMessage(CCSUsrMsg_PlayerStatsUpdate.Stat)

CCSUsrMsg_DisplayInventory = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_DisplayInventory', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_DISPLAYINVENTORY,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_DisplayInventory)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_DisplayInventory)

CCSUsrMsg_QuestProgress = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_QuestProgress', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_QUESTPROGRESS,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_QuestProgress)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_QuestProgress)

CCSUsrMsg_ScoreLeaderboardData = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ScoreLeaderboardData', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SCORELEADERBOARDDATA,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ScoreLeaderboardData)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ScoreLeaderboardData)

CCSUsrMsg_PlayerDecalDigitalSignature = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_PlayerDecalDigitalSignature', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_PLAYERDECALDIGITALSIGNATURE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_PlayerDecalDigitalSignature)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_PlayerDecalDigitalSignature)

CCSUsrMsg_XRankGet = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_XRankGet', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_XRANKGET,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_XRankGet)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_XRankGet)

CCSUsrMsg_XRankUpd = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_XRankUpd', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_XRANKUPD,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_XRankUpd)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_XRankUpd)

CCSUsrMsg_CallVoteFailed = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_CallVoteFailed', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_CALLVOTEFAILED,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_CallVoteFailed)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_CallVoteFailed)

CCSUsrMsg_VoteStart = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VoteStart', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_VOTESTART,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VoteStart)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VoteStart)

CCSUsrMsg_VotePass = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VotePass', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_VOTEPASS,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VotePass)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VotePass)

CCSUsrMsg_VoteFailed = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VoteFailed', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_VOTEFAILED,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VoteFailed)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VoteFailed)

CCSUsrMsg_VoteSetup = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_VoteSetup', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_VOTESETUP,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_VoteSetup)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_VoteSetup)

CCSUsrMsg_SendLastKillerDamageToClient = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_SendLastKillerDamageToClient', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SENDLASTKILLERDAMAGETOCLIENT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_SendLastKillerDamageToClient)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_SendLastKillerDamageToClient)

CCSUsrMsg_ServerRankUpdate = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ServerRankUpdate', (_message.Message,), dict(

  RankUpdate = _reflection.GeneratedProtocolMessageType('RankUpdate', (_message.Message,), dict(
    DESCRIPTOR = _CCSUSRMSG_SERVERRANKUPDATE_RANKUPDATE,
    __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
    # @@protoc_insertion_point(class_scope:CCSUsrMsg_ServerRankUpdate.RankUpdate)
    ))
  ,
  DESCRIPTOR = _CCSUSRMSG_SERVERRANKUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ServerRankUpdate)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ServerRankUpdate)
_sym_db.RegisterMessage(CCSUsrMsg_ServerRankUpdate.RankUpdate)

CCSUsrMsg_XpUpdate = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_XpUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_XPUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_XpUpdate)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_XpUpdate)

CCSUsrMsg_ItemPickup = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ItemPickup', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_ITEMPICKUP,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ItemPickup)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ItemPickup)

CCSUsrMsg_ShowMenu = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ShowMenu', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SHOWMENU,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ShowMenu)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ShowMenu)

CCSUsrMsg_BarTime = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_BarTime', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_BARTIME,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_BarTime)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_BarTime)

CCSUsrMsg_AmmoDenied = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_AmmoDenied', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_AMMODENIED,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_AmmoDenied)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_AmmoDenied)

CCSUsrMsg_MarkAchievement = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_MarkAchievement', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_MARKACHIEVEMENT,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_MarkAchievement)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_MarkAchievement)

CCSUsrMsg_MatchStatsUpdate = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_MatchStatsUpdate', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_MATCHSTATSUPDATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_MatchStatsUpdate)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_MatchStatsUpdate)

CCSUsrMsg_ItemDrop = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ItemDrop', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_ITEMDROP,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ItemDrop)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ItemDrop)

CCSUsrMsg_GlowPropTurnOff = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_GlowPropTurnOff', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_GLOWPROPTURNOFF,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_GlowPropTurnOff)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_GlowPropTurnOff)

CCSUsrMsg_RoundBackupFilenames = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_RoundBackupFilenames', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_ROUNDBACKUPFILENAMES,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_RoundBackupFilenames)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_RoundBackupFilenames)

CCSUsrMsg_ResetHud = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ResetHud', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_RESETHUD,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ResetHud)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ResetHud)

CCSUsrMsg_GameTitle = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_GameTitle', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_GAMETITLE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_GameTitle)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_GameTitle)

CCSUsrMsg_RequestState = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_RequestState', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_REQUESTSTATE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_RequestState)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_RequestState)

CCSUsrMsg_StopSpectatorMode = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_StopSpectatorMode', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_STOPSPECTATORMODE,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_StopSpectatorMode)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_StopSpectatorMode)

CCSUsrMsg_DisconnectToLobby = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_DisconnectToLobby', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_DISCONNECTTOLOBBY,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_DisconnectToLobby)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_DisconnectToLobby)

CCSUsrMsg_WarmupHasEnded = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_WarmupHasEnded', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_WARMUPHASENDED,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_WarmupHasEnded)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_WarmupHasEnded)

CCSUsrMsg_ClientInfo = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ClientInfo', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_CLIENTINFO,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ClientInfo)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ClientInfo)

CCSUsrMsg_ServerRankRevealAll = _reflection.GeneratedProtocolMessageType('CCSUsrMsg_ServerRankRevealAll', (_message.Message,), dict(
  DESCRIPTOR = _CCSUSRMSG_SERVERRANKREVEALALL,
  __module__ = 'demoparser.protobufs.cstrike15_usermessages_pb2'
  # @@protoc_insertion_point(class_scope:CCSUsrMsg_ServerRankRevealAll)
  ))
_sym_db.RegisterMessage(CCSUsrMsg_ServerRankRevealAll)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\200\001\000'))
# @@protoc_insertion_point(module_scope)
